
/**
 * This will allow one of the options for VanishingScribble to 
 * have the line move off the screen to the right.
 * 
 * 
 * @author Steven Graff 
 */

import objectdraw.*;
import java.awt.*;

public class MovingLine extends ActiveObject
{

    // size and speed of falling lines
    private static final double INITIAL_X_SPEED = 0.0001;
    private static final int DELAY_TIME = 33;
    private static final int INITIAL_DELAY = 100;

    // the line controlled by this instance
    private Line line;

    // how far to fall before stopping and disappearing?
    private double xMax;

    // Draw a ball and start it falling.
    public MovingLine(Location start, Location end, DrawingCanvas aCanvas) {

        // draw the line at its initial position
        line = new Line(start, end, aCanvas);

        // ask the canvas how big it is so we know when to stop
        xMax = aCanvas.getWidth();

        // activate
        start();
    }

    // move the line repeatedly until it gets sucked off the screen
    public void run() {

        pause(INITIAL_DELAY);

        // start out with a slow fall, then accelerate
        double xSpeed = INITIAL_X_SPEED;

        while ((line.getStart().getX() <= xMax) ||
        (line.getEnd().getX() <= xMax)) {
            line.move(xSpeed, 0);
            xSpeed = xSpeed * 1.1;
            pause(DELAY_TIME);
        }
        line.removeFromCanvas();
    }
}

